@@ -36,6 +36,12 @@
 #include <arpa/inet.h>
 #endif
 
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+
+#include <unistd.h>
+#include <string.h>
 #include "hddtemp-plugin.h"
 
 const gchar *plugin_name = "hddtemp";
@@ -49,26 +55,25 @@ enum {
 	HDDTEMP_SOCKET_CONNECT_ERROR,
 	HDDTEMP_GIOCHANNEL_ERROR,
 	HDDTEMP_GIOCHANNEL_READ_ERROR
-	
+
 };
 
+static gchar buffer[HDDTEMP_OUTPUT_BUFFER_LENGTH];
+
 static const gchar *hddtemp_plugin_query_hddtemp_daemon(GError **error) {
 	int sockfd;
 	ssize_t n = 1;
-	gboolean first_run = FALSE;
-	gint output_length = 0;
+	guint output_length = 0;
+	static gboolean first_run = TRUE;
 	gchar *pc;
 
 	struct sockaddr_in address;
-	static char* buffer = NULL;
 	static GTimeVal previous_query_time;
 	GTimeVal current_query_time;
 
-	if (NULL == buffer) {
-		// initialise buffer and current time
-		buffer = g_new0(char, HDDTEMP_OUTPUT_BUFFER_LENGTH);
+	if (first_run) {
+		// initialise previous time
 		g_get_current_time(&previous_query_time);
-		first_run = TRUE;
 	}
 	g_get_current_time(&current_query_time);
 
@@ -83,41 +88,40 @@ static const gchar *hddtemp_plugin_query_hddtemp_daemon(GError **error) {
 			g_set_error(error, SENSORS_APPLET_PLUGIN_ERROR, HDDTEMP_SOCKET_OPEN_ERROR, "Error opening socket for hddtemp");
 			return NULL;
 		}
-		
+
 		address.sin_family = AF_INET;
 		address.sin_addr.s_addr = inet_addr(HDDTEMP_SERVER_IP_ADDRESS);
 		address.sin_port = htons(HDDTEMP_PORT_NUMBER);
 
-		if (connect(sockfd, (struct sockaddr *)&address, (socklen_t)sizeof(address)) == -1) {
+		if (connect(sockfd, (struct sockaddr *)&address,
+                            (socklen_t)sizeof(address)) == -1) {
 			g_set_error(error, SENSORS_APPLET_PLUGIN_ERROR, HDDTEMP_SOCKET_CONNECT_ERROR, "Error connecting to hddtemp daemon on port %i on %s", htons(HDDTEMP_PORT_NUMBER), HDDTEMP_SERVER_IP_ADDRESS);
+			close(sockfd);
 			return NULL;
 		}
-
+		memset(buffer, 0, sizeof(buffer));
 		pc = buffer;
-		while ((n = read(sockfd, pc, HDDTEMP_OUTPUT_BUFFER_LENGTH - output_length)) > 0) {
+		while ((n = read(sockfd, pc,
+                                 sizeof(buffer) - output_length)) > 0) {
 			output_length += n;
-			pc = &pc[n];
+			pc += n;
 		}
-		/* terminate with pipe if not already terminated */
-		if (buffer[n - 1] != '|') {
-			buffer[n++] = '|';
-		} 
-		/* always null terminate the end of the buffer
-		 * regardless of how much stuff is in it already */
-		buffer[output_length] = '\0';  
+		/* always null terminate the end of the buffer */
+		buffer[MIN(output_length, sizeof(buffer) - 1)] = '\0';
 		close(sockfd);
+		first_run = FALSE;
 	}
 
 	return buffer;
 }
-	
+
 static void hddtemp_plugin_get_sensors(GList **sensors) {
 	GError *error = NULL;
 	const gchar *hddtemp_output;
 	gchar **output_vector = NULL, **pv;
-	
+
 	hddtemp_output = hddtemp_plugin_query_hddtemp_daemon(&error);
-	
+
 	if (error) {
 		g_error_free(error);
 		return;
@@ -128,12 +132,12 @@ static void hddtemp_plugin_get_sensors(GList **sensors) {
 		return;
 	}
 
-	/* for each sensor the output will contain four strings ie 
+	/* for each sensor the output will contain four strings ie
 	   |/dev/hda|WDC WD800JB-00ETA0|32|C||/dev/hdb|???|ERR|*|
 	   note the repetition -----^ */
 
 	/*
-	  
+
 	  pv[0 + 5*n] empty
 	  pv[1 + 5*n] device name
 	  pv[2 + 5*n] disk label
@@ -144,9 +148,14 @@ static void hddtemp_plugin_get_sensors(GList **sensors) {
 	*/
 
 	pv = output_vector = g_strsplit(hddtemp_output, "|", -1);
-	
+
 	while(pv[1] != NULL) {
-		if (pv[2] != "" && pv [3] != "" && pv[4] != "" && (!(g_ascii_strcasecmp(pv[2], "???") == 0 || g_ascii_strcasecmp(pv[3], "ERR") == 0 || g_ascii_strcasecmp(pv[4], "*") == 0))) {
+		if (strcmp(pv[2], "") != 0 &&
+		    strcmp(pv[3], "") != 0 &&
+		    strcmp(pv[4], "") != 0 &&
+		    (!(g_ascii_strcasecmp(pv[2], "???") == 0 ||
+		       g_ascii_strcasecmp(pv[3], "ERR") == 0 ||
+		       g_ascii_strcasecmp(pv[4], "*") == 0))) {
                         sensors_applet_plugin_add_sensor(sensors,
                                                         pv[1], // must be dynamically allocated
                                                         pv[1], // must be dynamically allocated
@@ -156,24 +165,23 @@ static void hddtemp_plugin_get_sensors(GList **sensors) {
                                                         HDD_ICON,
                                                         DEFAULT_GRAPH_COLOR);
 		}
-		pv += 5; 
+		pv += 5;
 	}
 	g_strfreev(output_vector);
-        
 }
 
 /* to be called to setup for hddtemp sensors */
 static GList *hddtemp_plugin_init(void) {
 	GList *sensors = NULL;
-	hddtemp_plugin_get_sensors(&sensors);		
+	hddtemp_plugin_get_sensors(&sensors);
         return sensors;
 }
 
 
 /* returns the value of the sensor_list at the given iter, or if an
    error occurs, instatiates error with an error message */
-static gdouble hddtemp_plugin_get_sensor_value(const gchar *path, 
-						  const gchar *id, 
+static gdouble hddtemp_plugin_get_sensor_value(const gchar *path,
+						  const gchar *id,
 						  SensorType type,
 						  GError **error) {
 
@@ -193,9 +201,9 @@ static gdouble hddtemp_plugin_get_sensor_value(const gchar *path,
 		return sensor_value;
 	}
 
-	/* for each sensor the output will contain four strings ie 
+	/* for each sensor the output will contain four strings ie
 	   |/dev/hda|WDC WD800JB-00ETA0|32|C||/dev/hdb|???|ERR|*|
-	            note the repetition -----^ 
+	            note the repetition -----^
 
 	  pv[0 + 5*n] empty
 	  pv[1 + 5*n] device name
@@ -207,36 +215,36 @@ static gdouble hddtemp_plugin_get_sensor_value(const gchar *path,
 	*/
 
 	pv = output_vector = g_strsplit(hddtemp_output, "|", -1);
-	
+
 	while(pv[1] != NULL) {
 		if (g_ascii_strcasecmp(pv[1], path) == 0) {
 			sensor_value = (gfloat)(g_ascii_strtod(pv[3], NULL));
-	
+
 			/* always return sensor values in celsius */
 			if (pv[4][0] == 'F') {
 				sensor_value = (sensor_value - 32.0) * 5.0 / 9.0;
 			}
 			break;
 		}
-		pv += 5; 
+		pv += 5;
 	}
 	g_strfreev(output_vector);
-	
+
 	return (gdouble)sensor_value;
 }
 
-const gchar *sensors_applet_plugin_name(void) 
+const gchar *sensors_applet_plugin_name(void)
 {
         return plugin_name;
 }
 
-GList *sensors_applet_plugin_init(void) 
+GList *sensors_applet_plugin_init(void)
 {
         return hddtemp_plugin_init();
 }
 
-gdouble sensors_applet_plugin_get_sensor_value(const gchar *path, 
-                                                const gchar *id, 
+gdouble sensors_applet_plugin_get_sensor_value(const gchar *path,
+                                                const gchar *id,
                                                 SensorType type,
                                                 GError **error) {
         return hddtemp_plugin_get_sensor_value(path, id, type, error);
