@@ -26,9 +26,8 @@ void active_sensor_libnotify_notify(ActiveSensor *active_sensor,
                                     NotifType notif_type,
                                     const gchar *summary,
                                     const gchar *message,
-                                    const gchar *icon_filename,
-                                    gint timeout_msecs,
-                                    GtkWidget *attach);
+				    const gchar *icon_filename,
+                                    gint timeout_msecs);
 void active_sensor_libnotify_notify_end(ActiveSensor *active_sensor,
                                         NotifType notif_type);
 
